vfbLib.ufo.info.VfbToUfoInfo
============================

.. currentmodule:: vfbLib.ufo.info

.. autoclass:: VfbToUfoInfo
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~VfbToUfoInfo.__init__
      ~VfbToUfoInfo.build_mapping
      ~VfbToUfoInfo.fix_underline_position
      ~VfbToUfoInfo.read
      ~VfbToUfoInfo.set_attr
      ~VfbToUfoInfo.set_created_timestamp
      ~VfbToUfoInfo.set_fixed_pitch
      ~VfbToUfoInfo.set_name_records
      ~VfbToUfoInfo.set_selection
      ~VfbToUfoInfo.set_style_name
      ~VfbToUfoInfo.set_tt_gasp
      ~VfbToUfoInfo.set_tt_info
      ~VfbToUfoInfo.set_weight_class
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~VfbToUfoInfo.familyName
      ~VfbToUfoInfo.styleName
      ~VfbToUfoInfo.styleMapFamilyName
      ~VfbToUfoInfo.styleMapStyleName
      ~VfbToUfoInfo.versionMajor
      ~VfbToUfoInfo.versionMinor
      ~VfbToUfoInfo.copyright
      ~VfbToUfoInfo.trademark
      ~VfbToUfoInfo.unitsPerEm
      ~VfbToUfoInfo.descender
      ~VfbToUfoInfo.xHeight
      ~VfbToUfoInfo.capHeight
      ~VfbToUfoInfo.ascender
      ~VfbToUfoInfo.italicAngle
      ~VfbToUfoInfo.note
      ~VfbToUfoInfo.openTypeHeadCreated
      ~VfbToUfoInfo.openTypeHeadLowestRecPPEM
      ~VfbToUfoInfo.openTypeHeadFlags
      ~VfbToUfoInfo.openTypeHheaAscender
      ~VfbToUfoInfo.openTypeHheaDescender
      ~VfbToUfoInfo.openTypeHheaLineGap
      ~VfbToUfoInfo.openTypeHheaCaretSlopeRise
      ~VfbToUfoInfo.openTypeHheaCaretSlopeRun
      ~VfbToUfoInfo.openTypeHheaCaretOffset
      ~VfbToUfoInfo.openTypeNameDesigner
      ~VfbToUfoInfo.openTypeNameDesignerURL
      ~VfbToUfoInfo.openTypeNameManufacturer
      ~VfbToUfoInfo.openTypeNameManufacturerURL
      ~VfbToUfoInfo.openTypeNameLicense
      ~VfbToUfoInfo.openTypeNameLicenseURL
      ~VfbToUfoInfo.openTypeNameVersion
      ~VfbToUfoInfo.openTypeNameUniqueID
      ~VfbToUfoInfo.openTypeNameDescription
      ~VfbToUfoInfo.openTypeNamePreferredFamilyName
      ~VfbToUfoInfo.openTypeNamePreferredSubfamilyName
      ~VfbToUfoInfo.openTypeNameCompatibleFullName
      ~VfbToUfoInfo.openTypeNameSampleText
      ~VfbToUfoInfo.openTypeNameWWSFamilyName
      ~VfbToUfoInfo.openTypeNameWWSSubfamilyName
      ~VfbToUfoInfo.openTypeOS2WeightClass
      ~VfbToUfoInfo.openTypeOS2Selection
      ~VfbToUfoInfo.openTypeOS2VendorID
      ~VfbToUfoInfo.openTypeOS2Panose
      ~VfbToUfoInfo.openTypeOS2FamilyClass
      ~VfbToUfoInfo.openTypeOS2UnicodeRanges
      ~VfbToUfoInfo.openTypeOS2CodePageRanges
      ~VfbToUfoInfo.openTypeOS2TypoAscender
      ~VfbToUfoInfo.openTypeOS2TypoDescender
      ~VfbToUfoInfo.openTypeOS2TypoLineGap
      ~VfbToUfoInfo.openTypeOS2WinAscent
      ~VfbToUfoInfo.openTypeOS2WinDescent
      ~VfbToUfoInfo.openTypeOS2Type
      ~VfbToUfoInfo.openTypeOS2SubscriptXSize
      ~VfbToUfoInfo.openTypeOS2SubscriptYSize
      ~VfbToUfoInfo.openTypeOS2SubscriptXOffset
      ~VfbToUfoInfo.openTypeOS2SubscriptYOffset
      ~VfbToUfoInfo.openTypeOS2SuperscriptXSize
      ~VfbToUfoInfo.openTypeOS2SuperscriptYSize
      ~VfbToUfoInfo.openTypeOS2SuperscriptXOffset
      ~VfbToUfoInfo.openTypeOS2SuperscriptYOffset
      ~VfbToUfoInfo.openTypeOS2StrikeoutSize
      ~VfbToUfoInfo.openTypeOS2StrikeoutPosition
      ~VfbToUfoInfo.openTypeVheaVertTypoAscender
      ~VfbToUfoInfo.openTypeVheaVertTypoDescender
      ~VfbToUfoInfo.openTypeVheaVertTypoLineGap
      ~VfbToUfoInfo.openTypeVheaCaretSlopeRise
      ~VfbToUfoInfo.openTypeVheaCaretSlopeRun
      ~VfbToUfoInfo.openTypeVheaCaretOffset
      ~VfbToUfoInfo.postscriptFontName
      ~VfbToUfoInfo.postscriptFullName
      ~VfbToUfoInfo.postscriptSlantAngle
      ~VfbToUfoInfo.postscriptUniqueID
      ~VfbToUfoInfo.postscriptUnderlineThickness
      ~VfbToUfoInfo.postscriptUnderlinePosition
      ~VfbToUfoInfo.postscriptIsFixedPitch
      ~VfbToUfoInfo.postscriptBlueValues
      ~VfbToUfoInfo.postscriptOtherBlues
      ~VfbToUfoInfo.postscriptFamilyBlues
      ~VfbToUfoInfo.postscriptFamilyOtherBlues
      ~VfbToUfoInfo.postscriptStemSnapH
      ~VfbToUfoInfo.postscriptStemSnapV
      ~VfbToUfoInfo.postscriptBlueFuzz
      ~VfbToUfoInfo.postscriptBlueShift
      ~VfbToUfoInfo.postscriptBlueScale
      ~VfbToUfoInfo.postscriptForceBold
      ~VfbToUfoInfo.postscriptDefaultWidthX
      ~VfbToUfoInfo.postscriptNominalWidthX
      ~VfbToUfoInfo.postscriptWeightName
      ~VfbToUfoInfo.postscriptDefaultCharacter
      ~VfbToUfoInfo.postscriptWindowsCharacterSet
      ~VfbToUfoInfo.macintoshFONDName
      ~VfbToUfoInfo.macintoshFONDFamilyID
      ~VfbToUfoInfo.year
      ~VfbToUfoInfo.woffMajorVersion
      ~VfbToUfoInfo.woffMinorVersion
      ~VfbToUfoInfo.ds_family_name
      ~VfbToUfoInfo.ds_style_name
      ~VfbToUfoInfo.guidelines
      ~VfbToUfoInfo.json_dump
      ~VfbToUfoInfo.json_dumps
      ~VfbToUfoInfo.json_load
      ~VfbToUfoInfo.json_loads
      ~VfbToUfoInfo.msgpack_dump
      ~VfbToUfoInfo.msgpack_dumps
      ~VfbToUfoInfo.msgpack_load
      ~VfbToUfoInfo.msgpack_loads
      ~VfbToUfoInfo.openTypeGaspRangeRecords
      ~VfbToUfoInfo.openTypeNameRecords
      ~VfbToUfoInfo.openTypeOS2WidthClass
      ~VfbToUfoInfo.ui_name
      ~VfbToUfoInfo.woffMetadataCopyright
      ~VfbToUfoInfo.woffMetadataCredits
      ~VfbToUfoInfo.woffMetadataDescription
      ~VfbToUfoInfo.woffMetadataExtensions
      ~VfbToUfoInfo.woffMetadataLicense
      ~VfbToUfoInfo.woffMetadataLicensee
      ~VfbToUfoInfo.woffMetadataTrademark
      ~VfbToUfoInfo.woffMetadataUniqueID
      ~VfbToUfoInfo.woffMetadataVendor
   
   